@@ -1,13 +1,5 @@
-import os
-import sys
 import cv2
-__dir__ = os.path.dirname(__file__)
-
-# import paddle
-
-sys.path.append(os.path.join(__dir__, ''))
-
-from PaddleOCR.paddleocr import PaddleOCR
+from paddleocr import PaddleOCR
 import numpy as np
 import unicodedata as ud
 
@@ -72,7 +64,18 @@ class OcrLicense:
         output = {"name":"", "address":""}
         img = cv2.imread(img_path)
         h, w, _ = img.shape
+
+        if h < 450 or w < 700:
+            a = (700 / w)
+            b = (450 / h)
+            if a > b:
+                img = cv2.resize(img, (int(w*a), int(h*a)), interpolation= cv2.INTER_LINEAR)
+            else:
+                img = cv2.resize(img, (int(w*b), int(h*b)), interpolation= cv2.INTER_LINEAR)
+            h, w, _ = img.shape
+
         img = cv2.resize(img, (int(w*1.2), int(h*1.2)), interpolation= cv2.INTER_LINEAR)
+
         img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
         img = cv2.GaussianBlur(src=img, ksize=(3, 3), sigmaX=0, sigmaY=0)
         clahe = cv2.createCLAHE(clipLimit=2.5, tileGridSize=(12, 12))
@@ -162,5 +165,4 @@ class OcrLicense:
                 if output["name"] != "" and output["address"] != "":
                     break
 
-        return output
-OcrLicense()
\ No newline at end of file
+        return output
\ No newline at end of file
